==> core_models-0.1.0.gem: app/controllers/core_models/base/addresses_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::AddressesController < CoreModelsController
    # GET /base/addresses
    # GET /base/addresses.json
    def index
      @base_addresses = Base::Address.all
      #@base_address_markers = @base_addresses.to_gmaps4rails
      #@base_address_json = @base_address_markers.each  do |address, marker|
      #  marker.json "\"id\": #{address.id}"
      #end

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_addresses }
      end
    end

    # GET /base/addresses/1
    # GET /base/addresses/1.json
    def show
      @base_address = Base::Address.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_address }
      end
    end

    # GET /base/addresses/new
    # GET /base/addresses/new.json
    def new
      @base_address = Base::Address.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_address }
      end
    end

    # GET /base/addresses/1/edit
    def edit
      @base_address = Base::Address.find(params[:id])
    end

    # POST /base/addresses
    # POST /base/addresses.json
    def create
      @base_address = Base::Address.new(params[:base_address])

      respond_to do |format|
        if @base_address.save
          format.html { redirect_to @base_address, :notice => 'Address was successfully created.' }
          format.json { render :json => @base_address, :status => :created, :location => @base_address }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_address.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/addresses/1
    # PUT /base/addresses/1.json
    def update
      @base_address = Base::Address.find(params[:id])

      respond_to do |format|
        if @base_address.update_attributes(params[:base_address])
          format.html { redirect_to @base_address, :notice => 'Address was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_address.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/addresses/1
    # DELETE /base/addresses/1.json
    def destroy
      @base_address = Base::Address.find(params[:id])
      @base_address.destroy

      respond_to do |format|
        format.html { redirect_to base_addresses_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/addresses_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::AddressesController < CoreModelsController
    # GET /base/addresses
    # GET /base/addresses.json
    def index
      @base_addresses = Base::Address.all
      #@base_address_markers = @base_addresses.to_gmaps4rails
      #@base_address_json = @base_address_markers.each  do |address, marker|
      #  marker.json "\"id\": #{address.id}"
      #end

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_addresses }
      end
    end

    # GET /base/addresses/1
    # GET /base/addresses/1.json
    def show
      @base_address = Base::Address.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_address }
      end
    end

    # GET /base/addresses/new
    # GET /base/addresses/new.json
    def new
      @base_address = Base::Address.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_address }
      end
    end

    # GET /base/addresses/1/edit
    def edit
      @base_address = Base::Address.find(params[:id])
    end

    # POST /base/addresses
    # POST /base/addresses.json
    def create
      @base_address = Base::Address.new(params[:base_address])

      respond_to do |format|
        if @base_address.save
          format.html { redirect_to @base_address, :notice => 'Address was successfully created.' }
          format.json { render :json => @base_address, :status => :created, :location => @base_address }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_address.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/addresses/1
    # PUT /base/addresses/1.json
    def update
      @base_address = Base::Address.find(params[:id])

      respond_to do |format|
        if @base_address.update(params[:base_address])
          format.html { redirect_to @base_address, :notice => 'Address was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_address.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/addresses/1
    # DELETE /base/addresses/1.json
    def destroy
      @base_address = Base::Address.find(params[:id])
      @base_address.destroy

      respond_to do |format|
        format.html { redirect_to base_addresses_url }
        format.json { head :no_content }
      end
    end
  end
end
